package gpsys.cos;

import gpsys.*;

/**
 * <pre>
 *	Vector2Mod10 ADF1
 * </pre>
 *
 * ADF1 is an automatically defined Terminal.  This is just a wraparound that
 * allows the ADF to be added to the terminal set of other ADFs.  The actual
 * body of ADF1 is in Chromosome 1 (adf[1]) of an Individual.
 *
 * @see gpsys.Primitive
 * @see gpsys.Terminal
 * @see gpsys.ADTerminal
 *
 * @version             1.1, 24 Mars 1999
 * @author      <a href="mailto:epierre@e-nef.com">Emmanuel PIERRE</a>
 *                      <address>DEA IARFA,</address>
 *
 */
public class ADF1 extends ADTerminal {

	/**
	 * Construct an ADF1 terminal assigning its type to Vector2Mod10.
	 */
	public ADF1() {
		adfIndex = 1;	// index to the chromosome containing the body
		type = CosSimTypes.Vector2Mod10;
	}

	/**
	 * Evaluate the evolved terminal as primitive that returns an Object
	 * reference.
	 *
	 * @param i	The individual containing the evolved body for this ADF
	 * @return An Object reference representing the result of the evaluation.
	 * @exception	EvaluationException	If there is an evaluation failure.
	 */
	public Object evaluateObject(Individual i)
	throws EvaluationException {
		Gene body = i.adf[adfIndex].treeTop;
		return body.evaluateObject(i);
	}

	/**
	 * Create another instance of this ADTerminal.
	 *
	 * @return	Since all the instance variable are to be the same, we just
	 *			return a reference to the same object.
	 */
	public Primitive instance() {
		return this;
	}

	/**
	 * Returns a String representation of this ADTerminal.
	 *
	 * @return A String containing the name of the ADTerminal.
	 */
	public String toString() {
		return "ADF1";
	}
}
